﻿// This file is part of SaladSlicer. SaladSlicer is licensed 
// under the terms of GNU General Public License as published 
// by the Free Software Foundation. For more information and the 
// LICENSE file, see <https://github.com/3DCP-TUe/SaladSlicer>.

// Salad Libs
using SaladSlicer.CodeGeneration;

namespace SaladSlicer.Interfaces
{
    /// <summary>
    /// Represents the interface for all classes that can generate code lines for a program.
    /// </summary>
    public interface IProgram
    {
        #region constructors
        /// <summary>
        /// Returns an exact duplicate of this IProgram.
        /// </summary>
        /// <returns> The exact duplicate of this IProgram. </returns>
        IProgram DuplicateProgramObject();
        #endregion

        #region methods
        /// <summary>
        /// Adds the NC program lines generated by this object to the program.
        /// </summary>
        /// <param name="programGenerator"> The program generator. </param>
        void ToProgram(ProgramGenerator programGenerator);

        /// <summary>
        /// Collects the data of this object to the program generator to generate the path.
        /// </summary>
        /// <param name="programGenerator"> The program generator. </param>
        void ToPath(ProgramGenerator programGenerator);

        /// <summary>
        /// Returns the Program Object as a single CodeLine.
        /// </summary>
        string ToSingleString();
        #endregion

        #region properties
        /// <summary>
        /// Gets a value indicating whether or not the object is valid.
        /// </summary>
        bool IsValid { get; }
        #endregion
    }
}
